# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _targetfile_postfix common.target
%else
  %global _servicefile_postfix init
%endif

Summary: Multipurpose relay for bidirectional data transfer
Name: socat
Version: 1.8.0.3
Release: 1%{?dist}
License: GPL-2.0-or-later
Group: Applications/System
URL: http://www.dest-unreach.org/socat/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: http://www.dest-unreach.org/socat/download/%{name}-%{version}.tar.bz2
%if %{_has_systemd}
Source1: %{name}@.%{_servicefile_postfix}
Source100: %{name}.%{_targetfile_postfix}
%else
Source1: %{name}.%{_servicefile_postfix}
%endif
Source2: %{name}.sysconfig
Source3: %{name}.conf.sample
Source4: %{name}-execpriv.defaults
Source5: %{name}.README
Patch0: socat-1.8.0.3-warn.patch
Requires: %{name}-init = %{version}-%{release}
BuildRequires: readline-devel, openssl-devel, sed
BuildRoot: %{_tmppath}/%{name}-%{version}-root
%if %{_has_systemd}
BuildRequires: systemd
%endif

%description
Socat (for SOcket CAT) establishes two bidirectional byte streams
and transfers data between them. Data channels may be files, pipes,
devices (terminal or modem, etc.), or sockets (Unix, IPv4, IPv6, raw,
UDP, TCP, SSL). It provides forking, logging and tracing, different
modes for interprocess communication and many more options.
It can be used, for example, as a TCP relay (one-shot or daemon),
as an external socksifier, as a shell interface to Unix sockets,
as an IPv6 relay, as a netcat and rinetd replacement, to redirect
TCP-oriented programs to a serial line, or to establish a relatively
secure environment (su and chroot) for running client or server shell
scripts inside network connections.

%package init
Summary: Init scripts or systemd unit files for running socat
Group: System Environment/Daemons
# only >= EL6 support mixed build archs
%{!?_sub_arch: %global _sub_arch noarch}
BuildArch: %{_sub_arch}
# this is to allow distribution package if it has a usable version
Requires: %{name} >= %{version}
Requires: exec-tools >= 0.9
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

%description init
This package includes init scripts or systemd unit files for running
socat as daemon(s). Based on configuration files, one or multiple
socat instancesare managed on system startup or shutdown.

%prep
%setup -q
%patch0 -p1 -b .warn
%{__chmod} a-x *.sh
# Not needed on newer distributions
%{__sed} -i -e "s|^#\! */usr/bin/env *bash$|#\!/bin/bash|g" *.sh

%build
%configure --disable-fips --disable-libwrap
%{__make}

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_sysconfdir}/%{name}.d

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -d %{buildroot}%{_unitdir}-generators
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}@.service
%{__install} -m 0644 -p %{SOURCE100} %{buildroot}%{_unitdir}/%{name}.target
%{__ln_s} -f execpriv-generator %{buildroot}%{_unitdir}-generators/%{name}-generator
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.d/
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}.d/execpriv.defaults
%{__install} -m 0644 -p %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}.d/README

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p"

# Symlinks in docs
%{__mv} -vf socat-broker.sh socat-broker.sh.orig
%{__mv} -vf socat-chain.sh socat-chain.sh.orig
%{__mv} -vf socat-mux.sh socat-mux.sh.orig
%{__ln_s} -f ../../../bin/socat-broker.sh socat-broker.sh
%{__ln_s} -f ../../../bin/socat-chain.sh socat-chain.sh
%{__ln_s} -f ../../../bin/socat-mux.sh socat-mux.sh

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post init
%if %{_has_systemd}
%systemd_post %{name}.target
%else
/sbin/chkconfig --add %{name}
%endif

%preun init
%if %{_has_systemd}
%systemd_preun %{name}.target
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi
%endif

%postun init
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.target
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc BUGREPORTS CHANGES COPYING* DEVELOPMENT EXAMPLES FAQ FILES PORTING README* SECURITY
%doc *.sh doc/*.css doc/*.html
%{_bindir}/%{name}
%{_bindir}/%{name}1
%{_bindir}/procan
%{_bindir}/filan
%{_bindir}/socat-broker.sh
%{_bindir}/socat-chain.sh
%{_bindir}/socat-mux.sh
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}1.1*

%files init
%defattr(-,root,root,-)
%if %{_has_systemd}
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}.target
%{_unitdir}-generators/%{name}-generator
%else
%config %{_initrddir}/%{name}
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_sysconfdir}/%{name}.d
%config(noreplace) %{_sysconfdir}/%{name}.d/%{name}.conf.sample
%config(noreplace) %{_sysconfdir}/%{name}.d/execpriv.defaults
%{_sysconfdir}/%{name}.d/README

%changelog
* Sat Feb 22 2025 Simon Matter <simon.matter@invoca.ch> 1.8.0.3-1
- upgrade to 1.8.0.3

* Mon Jan 13 2025 Simon Matter <simon.matter@invoca.ch> 1.8.0.2-1
- upgrade to 1.8.0.2

* Mon Aug 26 2024 Simon Matter <simon.matter@invoca.ch> 1.8.0.1-1
- upgrade to 1.8.0.1

* Mon May 21 2024 Simon Matter <simon.matter@invoca.ch> 1.8.0.0-2
- start systemd units only after network-online target is reached

* Thu Nov 16 2023 Simon Matter <simon.matter@invoca.ch> 1.8.0.0-1
- upgrade to 1.8.0.0

* Wed Jun 21 2023 Simon Matter <simon.matter@invoca.ch> 1.7.4.4-2
- change to *.common.service systemd files
- remove eval where possible
- change to SPDX license tag

* Mon Oct 31 2022 Simon Matter <simon.matter@invoca.ch> 1.7.4.4-1
- upgrade to 1.7.4.4

* Mon Jan 10 2022 Simon Matter <simon.matter@invoca.ch> 1.7.4.3-1
- upgrade to 1.7.4.3

* Mon Nov 01 2021 Simon Matter <simon.matter@invoca.ch> 1.7.4.2-1
- upgrade to 1.7.4.2

* Mon Jan 11 2021 Simon Matter <simon.matter@invoca.ch> 1.7.4.1-1
- upgrade to 1.7.4.1

* Wed Jan 06 2021 Simon Matter <simon.matter@invoca.ch> 1.7.4.0-1
- upgrade to 1.7.4.0

* Tue Apr 14 2020 Simon Matter <simon.matter@invoca.ch> 1.7.3.4-2
- add support for EL8

* Mon Jan 06 2020 Simon Matter <simon.matter@invoca.ch> 1.7.3.4-1
- upgrade to 1.7.3.4

* Mon Apr 08 2019 Simon Matter <simon.matter@invoca.ch> 1.7.3.3-1
- upgrade to 1.7.3.3

* Wed Nov 21 2018 Simon Matter <simon.matter@invoca.ch> 1.7.3.2-8
- update for compatibility with exec-tools >= 0.9

* Tue Nov 20 2018 Simon Matter <simon.matter@invoca.ch> 1.7.3.2-6
- update for compatibility with exec-tools >= 0.8

* Fri Nov 16 2018 Simon Matter <simon.matter@invoca.ch> 1.7.3.2-5
- update for compatibility with exec-tools >= 0.5

* Mon Jul 23 2018 Simon Matter <simon.matter@invoca.ch> 1.7.3.2-4
- add patch to fix documentation of commonname option

* Wed Sep 27 2017 Simon Matter <simon.matter@invoca.ch> 1.7.3.2-3
- cosmetic spec file changes

* Fri Sep 08 2017 Simon Matter <simon.matter@invoca.ch> 1.7.3.2-2
- split out init components into sub package

* Mon Jan 30 2017 Simon Matter <simon.matter@invoca.ch> 1.7.3.2-1
- upgrade to 1.7.3.2

* Tue Feb 02 2016 Simon Matter <simon.matter@invoca.ch> 1.7.3.1-1
- upgrade to 1.7.3.1

* Tue Jun 09 2015 Simon Matter <simon.matter@invoca.ch> 1.7.3.0-5
- small fixes for systemd

* Tue Apr 14 2015 Simon Matter <simon.matter@invoca.ch> 1.7.3.0-4
- small init fixes

* Fri Apr 10 2015 Simon Matter <simon.matter@invoca.ch> 1.7.3.0-3
- add support for systemd

* Thu Feb 19 2015 Simon Matter <simon.matter@invoca.ch> 1.7.3.0-2
- add error patch

* Mon Jan 26 2015 Simon Matter <simon.matter@invoca.ch> 1.7.3.0-1
- upgrade to 1.7.3.0

* Mon Mar 10 2014 Simon Matter <simon.matter@invoca.ch> 1.7.2.4-1
- upgrade to 1.7.2.4

* Wed Jan 29 2014 Simon Matter <simon.matter@invoca.ch> 1.7.2.3-1
- upgrade to 1.7.2.3

* Mon May 27 2013 Simon Matter <simon.matter@invoca.ch> 1.7.2.2-1
- upgrade to 1.7.2.2

* Tue May 15 2012 Simon Matter <simon.matter@invoca.ch> 1.7.2.1-1
- upgrade to 1.7.2.1

* Mon Dec 19 2011 Simon Matter <simon.matter@invoca.ch> 1.7.2.0-1
- upgrade to 1.7.2.0

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 1.7.1.3-2
- mass rebuild

* Mon Aug 02 2010 Simon Matter <simon.matter@invoca.ch> 1.7.1.3-1
- upgrade to 1.7.1.3

* Mon Jan 11 2010 Simon Matter <simon.matter@invoca.ch> 1.7.1.2-1
- upgrade to 1.7.1.2

* Thu May 07 2009 Simon Matter <simon.matter@invoca.ch> 1.7.1.1-1
- upgrade to 1.7.1.1

* Fri Apr 03 2009 Simon Matter <simon.matter@invoca.ch> 1.7.1.0-1
- upgrade to 1.7.1.0

* Thu Apr 02 2009 Simon Matter <simon.matter@invoca.ch> 1.7.0.1-1
- upgrade to 1.7.0.1

* Thu Oct 16 2008 Simon Matter <simon.matter@invoca.ch> 1.7.0.0-1
- upgrade to 1.7.0.0

* Mon Feb 11 2008 Simon Matter <simon.matter@invoca.ch> 1.6.0.1-1
- upgrade to 1.6.0.1
- add service init facility

* Fri Feb 08 2008 Simon Matter <simon.matter@invoca.ch> 1.6.0.0-1
- initial package
